<?php
/**
 * Wishlist page template - Standard Layout
 *
 * @author YITH
 * @package YITH\Wishlist\Templates\Wishlist\View
 * @version 3.0.0
 */

/**
 * Template variables:
 *
 * @var $wishlist                      \YITH_WCWL_Wishlist Current wishlist
 * @var $wishlist_items                array Array of items to show for current page
 * @var $wishlist_token                string Current wishlist token
 * @var $wishlist_id                   int Current wishlist id
 * @var $users_wishlists               array Array of current user wishlists
 * @var $pagination                    string yes/no
 * @var $per_page                      int Items per page
 * @var $current_page                  int Current page
 * @var $page_links                    array Array of page links
 * @var $is_user_owner                 bool Whether current user is wishlist owner
 * @var $show_price                    bool Whether to show price column
 * @var $show_dateadded                bool Whether to show item date of addition
 * @var $show_stock_status             bool Whether to show product stock status
 * @var $show_add_to_cart              bool Whether to show Add to Cart button
 * @var $show_remove_product           bool Whether to show Remove button
 * @var $show_price_variations         bool Whether to show price variation over time
 * @var $show_variation                bool Whether to show variation attributes when possible
 * @var $show_cb                       bool Whether to show checkbox column
 * @var $show_quantity                 bool Whether to show input quantity or not
 * @var $show_ask_estimate_button      bool Whether to show Ask an Estimate form
 * @var $show_last_column              bool Whether to show last column (calculated basing on previous flags)
 * @var $move_to_another_wishlist      bool Whether to show Move to another wishlist select
 * @var $move_to_another_wishlist_type string Whether to show a select or a popup for wishlist change
 * @var $additional_info               bool Whether to show Additional info textarea in Ask an estimate form
 * @var $price_excl_tax                bool Whether to show price excluding taxes
 * @var $enable_drag_n_drop            bool Whether to enable drag n drop feature
 * @var $repeat_remove_button          bool Whether to repeat remove button in last column
 * @var $available_multi_wishlist      bool Whether multi wishlist is enabled and available
 * @var $no_interactions               bool
 */

if ( ! defined( 'YITH_WCWL' ) ) {
	exit;
} // Exit if accessed directly
?>

<?php do_action( 'yith_wcwl_before_wishlist_form', $wishlist ); ?>

<form id="yith-wcwl-form" class="<?php echo (count($wishlist_items)> 0) ? '' : 'wishlist-empty'; ?>" action="<?php echo esc_attr($form_action) ?>" method="post">
	
	<?php wp_nonce_field( 'yith-wcwl-form', 'yith_wcwl_form_nonce' ) ?>
	
    <!-- TITLE -->
    <?php
    do_action( 'yith_wcwl_before_wishlist_title' );

    if( ! empty( $page_title ) ) :
    ?>
        <div class="wishlist-title <?php echo ( $is_custom_list ) ? 'wishlist-title-with-form' : ''?>">
            <?php echo apply_filters( 'yith_wcwl_wishlist_title', '<h2>' . $page_title . '</h2>' ); ?>
            <?php if( $is_custom_list ): ?>
                <a class="btn button show-title-form">
                    <?php echo apply_filters( 'yith_wcwl_edit_title_icon', '<i class="fa fa-pencil"></i>' )?>
                    <?php esc_html_e( 'Edit title', 'dfd' ) ?>
                </a>
            <?php endif; ?>
        </div>
        <?php if( $is_custom_list ) : ?>
            <div class="hidden-title-form">
                <input type="text" value="<?php echo esc_attr($page_title) ?>" name="wishlist_name"/>
                <button>
                    <?php echo apply_filters( 'yith_wcwl_save_wishlist_title_icon', '<i class="fa fa-check"></i>' )?>
                    <?php esc_html_e( 'Save', 'dfd' )?>
                </button>
                <a class="hide-title-form btn button">
                    <?php echo apply_filters( 'yith_wcwl_cancel_wishlist_title_icon', '<i class="fa fa-remove"></i>' )?>
                    <?php esc_html_e( 'Cancel', 'dfd' )?>
                </a>
            </div>
        <?php endif; ?>
    <?php
    endif;

	do_action( 'yith_wcwl_before_wishlist' ); ?>

    <!-- WISHLIST TABLE -->
    <table class="shop_table cart wishlist_table" cellspacing="0" data-pagination="<?php echo esc_attr( $pagination )?>" data-per-page="<?php echo esc_attr( $per_page )?>" data-page="<?php echo esc_attr( $current_page )?>" data-id="<?php echo esc_attr($wishlist_id) ?>" data-token="<?php echo esc_attr($wishlist_token) ?>">
		<thead>
		<tr>
			<?php if( $show_cb ) : ?>
				<th class="product-checkbox">
					<input type="checkbox" value="" name="" id="bulk_add_to_cart"/>
				</th>
			<?php endif; ?>

			<?php if( $is_user_owner ): ?>
			<th class="product-remove"></th>
			<?php endif; ?>

			<th class="product-thumbnail"></th>

			<th class="product-name">
				<span class="nobr"><?php echo apply_filters( 'yith_wcwl_wishlist_view_name_heading', __( 'Product Name', 'dfd' ) ) ?></span>
			</th>

			<?php if( $show_price ) : ?>
				<th class="product-price">
					<span class="nobr">
						<?php echo apply_filters( 'yith_wcwl_wishlist_view_price_heading', __( 'Unit Price', 'dfd' ) ) ?>
					</span>
				</th>
			<?php endif ?>

			<?php if( $show_stock_status ) : ?>
				<th class="product-stock-stauts">
					<span class="nobr">
						<?php echo apply_filters( 'yith_wcwl_wishlist_view_stock_heading', __( 'Stock Status', 'dfd' ) ) ?>
					</span>
				</th>
			<?php endif ?>

			<?php if( $show_add_to_cart ) : ?>
				<th class="product-add-to-cart"></th>
			<?php endif ?>
		</tr>
		</thead>

		<tbody>
        <?php
        if( count( $wishlist_items ) > 0 ) : ?>
			<?php foreach( $wishlist_items as $item ) :
                global $product;
	            if( function_exists( 'wc_get_product' ) ) {
		            $product = wc_get_product( $item['prod_id'] );
	            }
	            else{
		            $product = get_product( $item['prod_id'] );
	            }

                if( $product !== false && $product->exists() ) :
	                $availability = $product->get_availability();
	                $stock_status = $availability['class'];
	                ?>
                    <tr id="yith-wcwl-row-<?php echo esc_attr($item['prod_id']) ?>" data-row-id="<?php echo esc_attr($item['prod_id']) ?>">
	                    <?php if( $show_cb ) : ?>
		                    <td class="product-checkbox">
			                    <input type="checkbox" value="<?php echo esc_attr( $item['prod_id'] ) ?>" name="add_to_cart[]" <?php echo ( $product->product_type != 'simple' ) ? 'disabled="disabled"' : '' ?>/>
		                    </td>
	                    <?php endif ?>
                        <?php if( $is_user_owner ): ?>
                        <td class="product-remove">
                            <div>
                                <a href="<?php echo esc_url( $item->get_remove_url() ); ?>" class="remove remove_from_wishlist" title="<?php esc_attr_e( 'Remove this product', 'dfd' ) ?>">&times;</a>
                            </div>
                        </td>
                        <?php endif; ?>

                        <td class="product-thumbnail">
                            <a href="<?php echo esc_url( get_permalink( apply_filters( 'woocommerce_in_cart_product', $item['prod_id'] ) ) ) ?>">
                                <?php echo wp_kses_post($product->get_image()) ?>
                            </a>
                        </td>

                        <td class="product-name">
                            <a href="<?php echo esc_url( get_permalink( apply_filters( 'woocommerce_in_cart_product', $item['prod_id'] ) ) ) ?>"><?php echo apply_filters( 'woocommerce_in_cartproduct_obj_title', $product->get_title(), $product ) ?></a>
                        </td>

                        <?php if( $show_price ) : ?>
                            <td class="product-price">
                                <?php echo ($product->get_price()) ? wp_kses_post($product->get_price_html()) : apply_filters( 'yith_free_text', esc_html__( 'Free!', 'dfd' ) ); ?>
                            </td>
                        <?php endif ?>

                        <?php if( $show_stock_status ) : ?>
                            <td class="product-stock-status">
                                <?php
                                if( $stock_status == 'out-of-stock' ) {
                                    $stock_status = "Out";
                                    echo '<span class="wishlist-out-of-stock">' . esc_html__( 'Out of Stock', 'dfd' ) . '</span>';
                                } else {
                                    $stock_status = "In";
                                    echo '<span class="wishlist-in-stock">' . esc_html__( 'In Stock', 'dfd' ) . '</span>';
                                }
                                ?>
                            </td>
                        <?php endif ?>

                        <?php if( $show_add_to_cart ) : ?>
                            <td class="product-add-to-cart">
                                <?php if( isset( $stock_status ) && $stock_status != 'Out' ): ?>
                                    <?php
                                    if( function_exists( 'wc_get_template' ) ) {
                                        wc_get_template( 'loop/add-to-cart.php' );
                                    }
                                    else{
                                        wc_get_template( 'loop/add-to-cart.php' );
                                    }
                                    ?>
                                <?php endif ?>
                            </td>
                        <?php endif ?>
                    </tr>
                <?php
                endif;
            endforeach;
        else: ?>
            <td colspan="6" class="wishlist-empty">
				<h1><?php esc_html_e('Wish', 'dfd') ?></h1>
				<p class="wishlist-empty-text"><?php esc_html_e( 'No products in the list', 'dfd' ) ?></p>
				<?php if(class_exists('WooCommerce')) : ?>
					<p class="wishlist-empty-subtext"><?php esc_html_e('Check the shop to find great items that you will definitely like', 'dfd') ?></p>
					<p class="return-to-shop"><a class="button wc-backward" href="<?php echo apply_filters( 'woocommerce_return_to_shop_redirect', get_permalink( wc_get_page_id( 'shop' ) ) ); ?>"><?php esc_html_e( 'Return To Shop', 'dfd' ) ?></a></p>
				<?php endif; ?>
			</td>
        <?php
        endif;

        if( ! empty( $page_links ) ) : ?>
            <tr>
                <td colspan="6"><?php echo wp_kses_post($page_links) ?></td>
            </tr>
        <?php endif ?>
        </tbody>

        <?php if( $is_user_logged_in ): ?>
            <tfoot>
            <tr>
	            <?php if( $show_cb ) : ?>
		            <td class="product-checkbox" >
			            <a href="#" class="button alt" id="custom_add_to_cart"><?php echo esc_attr( $add_to_cart_text )?></a>
		            </td>
	            <?php endif; ?>

                <?php if ( $is_user_owner && $share_enabled ) : ?>
                    <td colspan="<?php echo ( $is_user_logged_in && $is_user_owner && $show_ask_estimate_button && $count > 0 ) ? 4 : 6 ?>">
                        <?php yith_wcwl_get_template( 'share.php', $share_atts ); ?>
                    </td>
                <?php endif; ?>

                <?php
                if ( $is_user_owner && $show_ask_estimate_button && $count > 0 ): ?>
                    <td colspan="<?php echo ( $is_user_owner && $share_enabled ) ? 2 : 6 ?>">
                        <a href="<?php echo ( $additional_info ) ? '#ask_an_estimate_popup' : $ask_estimate_url ?>" class="btn button ask-an-estimate-button" <?php echo ( $additional_info ) ? 'data-rel="prettyPhoto[ask_an_estimate]"' : '' ?> >
                            <?php echo apply_filters( 'yith_wcwl_ask_an_estimate_icon', '<i class="fa fa-shopping-cart"></i>' )?>
                            <?php esc_html_e( 'Ask an estimate of costs', 'dfd' ) ?>
                        </a>
                    </td>
                <?php
                endif;
                ?>

                <?php do_action( 'yith_wcwl_after_wishlist_share' ); ?>
            </tr>
            </tfoot>
        <?php endif; ?>

    </table>

    <?php wp_nonce_field( 'yith_wcwl_edit_wishlist_action', 'yith_wcwl_edit_wishlist' ); ?>

    <?php if( $is_default ): ?>
        <input type="hidden" value="<?php echo esc_attr($wishlist_token) ?>" name="wishlist_id" id="wishlist_id">
    <?php endif; ?>

    <?php do_action( 'yith_wcwl_after_wishlist' ); ?>
</form>

<?php do_action( 'yith_wcwl_after_wishlist_form', $wishlist ); ?>

<?php if( $additional_info ): ?>
	<div id="ask_an_estimate_popup">
		<form action="<?php echo $ask_estimate_url ?>" method="post">
			<?php if( ! empty( $additional_info_label ) ):?>
				<label for="additional_notes"><?php echo esc_html( $additional_info_label ) ?></label>
			<?php endif; ?>
			<textarea id="additional_notes" name="additional_notes"></textarea>

			<button class="btn button ask-an-estimate-button ask-an-estimate-button-popup" >
				<?php echo apply_filters( 'yith_wcwl_ask_an_estimate_icon', '<i class="fa fa-shopping-cart"></i>' )?>
				<?php _e( 'Ask an estimate of costs', 'dfd' ) ?>
			</button>
		</form>
	</div>
<?php endif; ?>